@@ -28,17 +28,9 @@
 #include <QTranslator>
 #include <QLocale>
 
-#if QT_VERSION < 0x040300
-#define lighter(x)	light(x)
-#define darker(x)	dark(x)
-#endif
-
 #if QT_VERSION < 0x040500
 namespace Qt {
 const WindowFlags WindowCloseButtonHint = WindowFlags(0x08000000);
-#if QT_VERSION < 0x040200
-const WindowFlags CustomizeWindowHint   = WindowFlags(0x02000000);
-#endif
 }
 #endif
 
@@ -65,6 +57,8 @@ const WindowFlags CustomizeWindowHint   = WindowFlags(0x02000000);
 
 #if defined(Q_WS_X11)
 
+#include <unistd.h>
+
 #include <QX11Info>
 
 #include <X11/Xatom.h>
