@@ -1,7 +1,7 @@
 // qjackctlSetup.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2012, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2013, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -92,6 +92,9 @@ public:
 	// Destructor;
 	~qjackctlSetup();
 
+	// The settings object accessor.
+	QSettings& settings();
+
 	// Explicit I/O methods.
 	void loadSetup();
 	void saveSetup();
