@@ -1,7 +1,7 @@
 // qjackctlSetupForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2012, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2013, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -54,9 +54,6 @@ public slots:
 
 	void changeAudio(int);
 	void changeDriver(const QString&);
-	void selectInterface();
-	void selectInDevice();
-	void selectOutDevice();
 
 	void symbolStartupScript();
 	void symbolPostStartupScript();
@@ -100,7 +97,6 @@ protected:
 	void changeDriverAudio( const QString& sDriver, int iAudio );
 	void changeDriverUpdate( const QString& sDriver, bool bUpdate );
 
-	void deviceMenu(QLineEdit * pLineEdit, QToolButton * pToolButton, int iAudio);
 	void symbolMenu(QLineEdit * pLineEdit, QToolButton * pToolButton );
 
 	void stabilizeForm();
